==> payroll_ver_3.3.1.zip: payroll3/src/jp/mosp/kintai/report/vo/ExportCardVo.java <==
/*
 * MosP - Mind Open Source Project    http://www.mosp.jp/
 * Copyright (C) MIND Co., Ltd.       http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.kintai.report.vo;

import java.util.Iterator;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import jp.mosp.common.CommonConst;
import jp.mosp.common.MosPVo;
import jp.mosp.common.utils.StringUtil;
import jp.mosp.kintai.report.dto.MExportDto;

public class ExportCardVo extends MosPVo {
	
	private static final long	serialVersionUID	= -1964891218805898322L;
	
	// 萔
	public static final int		SEARCH_OFF			= 0;
	public static final int		SEARCH_ON			= 1;
	
	// p[^[
	public static final String	PRM_PLT_YEAR		= "pltYear";
	public static final String	PRM_PLT_MONTH		= "pltMonth";
	public static final String	PRM_TXT_E_NAME		= "txtEName";
	public static final String	PRM_TXT_E_FILE		= "txtEFile";
	
	// tB[h
	private String				pltYear;
	private String				pltMonth;
	
	private String[]			aryEName;
	private String[]			aryEFile;
	/*						
	 *  	2009/02/20	m.yoshida	G[Ή
	 */
	private String[]			aryENameKey;
	private String				txtEName;
	private String				txtEFile;
	
	// v_EXg
	public String[][]			aryPltYear;
	public String[][]			aryPltMonth;
	
	// tB[hyѐ
	public String				NAM_E_NAME;
	public String				NAM_E_FILE;
	public String				NAM_KINTAI_INFO;
	public String				NAM_PLT_YEAR;
	public String				NAM_PLT_MONTH;
	public int					LEN_E_NAME;
	
	// \[gL[
	public final String			KEY_E_NAME			= "keyEName";
	
	// [h(0FȂA1F)
	private int					searchmode;
	

	/**
	 * RXgN^
	 */
	public ExportCardVo() {
		super();
		setViewPath(getClassName());
		pltYear = "";
		pltMonth = "";
		aryEName = new String[0];
		aryEFile = new String[0];
		setFormerKey(KEY_E_NAME);
		/*						
		 *  	2009/02/20	m.yoshida	G[Ή
		 */
		aryENameKey = new String[0];
	}
	
	@Override
	protected void setSubTitle() {
		subTitle = CommonConst.TTL_EXPORT_MASTER;
		aryMenu = new String[][]{ { CMD_MENU_PAYROLL, CommonConst.NAM_TO_MENU } };
	}
	
	@Override
	protected void setFieldsName() {
		NAM_E_NAME = CommonConst.NAM_COMMON_MEISYO;
		NAM_E_FILE = CommonConst.NAM_TABLE;
		NAM_KINTAI_INFO = CommonConst.NAM_TARGET_MONTH;
		NAM_PLT_YEAR = CommonConst.NAM_YEAR;
		NAM_PLT_MONTH = CommonConst.NAM_MONTH;
		LEN_E_NAME = 10;
	}
	
	@Override
	public void setParams(HttpServletRequest request) {
		pltYear = request.getParameter(PRM_PLT_YEAR);
		pltMonth = request.getParameter(PRM_PLT_MONTH);
	}
	
	/**
	 * tB[hݒ
	 * @param exportList GNX|[g}X^Xg
	 */
	public void setFields(List<?> exportList) {
		//Xg̐ݒ
		list = exportList;
		//f[^̎擾
		count = exportList.size();
		//z̏
		aryEName = new String[count];
		aryEFile = new String[count];
		/*						
		 *  	2009/02/20	m.yoshida	G[Ή
		 */
		aryENameKey = new String[count];
		//f[^̐ݒ
		int i = 0;
		Iterator<?> it = exportList.iterator();
		while (it.hasNext()) {
			MExportDto dto = (MExportDto)it.next();
			String ename = "";
			String[] divName = StringUtil.divideByComma(dto.getEName());
			if (divName.length == 1) {
				ename = dto.getEName();
			} else {
				ename = divName[1];
			}
			aryEName[i] = escapeHTML(ename);
			aryEFile[i] = escapeHTML(dto.getEFile());
			aryENameKey[i] = escapeHTML(dto.getEName());
			i++;
		}
	}
	
	@Override
	public String getDirectJs(Class<?> cls, Object obj) throws IllegalAccessException {
		StringBuffer sb = new StringBuffer();
		sb.append(super.getDirectJs(cls, obj));
		return sb.toString();
	}
	
	// ANZTb\h
	public String[] getEscAryEName() {
		return aryEName.clone();
	}
	
	public String[] getEscAryEFile() {
		return aryEFile.clone();
	}
	
	/*						
	 *  	2009/02/20	m.yoshida	G[Ή
	 */
	public String[] getEscAryENameKey() {
		return aryENameKey.clone();
	}
	
	public String getPltYear() {
		return pltYear;
	}
	
	public String getPltMonth() {
		return pltMonth;
	}
	
	public String getEscTxtEName() {
		return escapeHTML(txtEName);
	}
	
	public String getTxtEName() {
		return txtEName;
	}
	
	public String getTxtEFile() {
		return txtEFile;
	}
	
	public void setPltYear(String pltYear) {
		this.pltYear = pltYear;
	}
	
	public void setPltMonth(String pltMonth) {
		this.pltMonth = pltMonth;
	}
	
	public String getEscPltYear() {
		return escapeHTML(pltYear);
	}
	
	public String getEscPltMonth() {
		return escapeHTML(pltMonth);
	}
	
	public void setTxtEName(String ename) {
		txtEName = ename;
	}
	
	public void setTxtEFile(String efile) {
		txtEFile = efile;
	}
	
	public void setSearchmode(int searchmode) {
		this.searchmode = searchmode;
	}
	
	public int getSearchmode() {
		return searchmode;
	}
	
}

==> payroll_ver_3.3.3.zip: payroll3/src/jp/mosp/kintai/report/vo/ExportCardVo.java <==
/*
 * MosP - Mind Open Source Project    http://www.mosp.jp/
 * Copyright (C) MIND Co., Ltd.       http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.kintai.report.vo;

import java.util.Iterator;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import jp.mosp.common.CommonConst;
import jp.mosp.common.MosPVo;
import jp.mosp.common.utils.StringUtil;
import jp.mosp.kintai.report.dto.MExportDto;

/**
 * 
 */
public class ExportCardVo extends MosPVo {
	
	private static final long	serialVersionUID	= -1964891218805898322L;
	
	// 萔
	/**
	 * 
	 */
	public static final int		SEARCH_OFF			= 0;
	/**
	 * 
	 */
	public static final int		SEARCH_ON			= 1;
	
	// p[^[
	/**
	 * 
	 */
	public static final String	PRM_PLT_YEAR		= "pltYear";
	/**
	 * 
	 */
	public static final String	PRM_PLT_MONTH		= "pltMonth";
	/**
	 * 
	 */
	public static final String	PRM_TXT_E_NAME		= "txtEName";
	/**
	 * 
	 */
	public static final String	PRM_TXT_E_FILE		= "txtEFile";
	
	// tB[h
	private String				pltYear;
	private String				pltMonth;
	
	private String[]			aryEName;
	private String[]			aryEFile;
	/*						
	 *  	2009/02/20	m.yoshida	G[Ή
	 */
	private String[]			aryENameKey;
	private String				txtEName;
	private String				txtEFile;
	
	// v_EXg
	/**
	 * 
	 */
	public String[][]			aryPltYear;
	/**
	 * 
	 */
	public String[][]			aryPltMonth;
	
	// tB[hyѐ
	/**
	 * 
	 */
	public String				NAM_E_NAME;
	/**
	 * 
	 */
	public String				NAM_E_FILE;
	/**
	 * 
	 */
	public String				NAM_KINTAI_INFO;
	/**
	 * 
	 */
	public String				NAM_PLT_YEAR;
	/**
	 * 
	 */
	public String				NAM_PLT_MONTH;
	/**
	 * 
	 */
	public int					LEN_E_NAME;
	
	// \[gL[
	/**
	 * 
	 */
	public final String			KEY_E_NAME			= "keyEName";
	
	// [h(0FȂA1F)
	private int					searchmode;
	

	/**
	 * RXgN^
	 */
	public ExportCardVo() {
		super();
		setViewPath(getClassName());
		pltYear = "";
		pltMonth = "";
		aryEName = new String[0];
		aryEFile = new String[0];
		setFormerKey(KEY_E_NAME);
		/*						
		 *  	2009/02/20	m.yoshida	G[Ή
		 */
		aryENameKey = new String[0];
	}
	
	@Override
	protected void setSubTitle() {
		subTitle = CommonConst.TTL_EXPORT_MASTER;
		aryMenu = new String[][]{ { CMD_MENU_PAYROLL, CommonConst.NAM_TO_MENU } };
	}
	
	@Override
	protected void setFieldsName() {
		NAM_E_NAME = CommonConst.NAM_COMMON_MEISYO;
		NAM_E_FILE = CommonConst.NAM_TABLE;
		NAM_KINTAI_INFO = CommonConst.NAM_TARGET_MONTH;
		NAM_PLT_YEAR = CommonConst.NAM_YEAR;
		NAM_PLT_MONTH = CommonConst.NAM_MONTH;
		LEN_E_NAME = 10;
	}
	
	@Override
	public void setParams(HttpServletRequest request) {
		pltYear = request.getParameter(PRM_PLT_YEAR);
		pltMonth = request.getParameter(PRM_PLT_MONTH);
	}
	
	@Override
	public void setFields(List<?> exportList) {
		//Xg̐ݒ
		list = exportList;
		//f[^̎擾
		count = exportList.size();
		//z̏
		aryEName = new String[count];
		aryEFile = new String[count];
		/*						
		 *  	2009/02/20	m.yoshida	G[Ή
		 */
		aryENameKey = new String[count];
		//f[^̐ݒ
		int i = 0;
		Iterator<?> it = exportList.iterator();
		while (it.hasNext()) {
			MExportDto dto = (MExportDto)it.next();
			String ename = "";
			String[] divName = StringUtil.divideByComma(dto.getEName());
			if (divName.length == 1) {
				ename = dto.getEName();
			} else {
				ename = divName[1];
			}
			aryEName[i] = escapeHTML(ename);
			aryEFile[i] = escapeHTML(dto.getEFile());
			aryENameKey[i] = escapeHTML(dto.getEName());
			i++;
		}
	}
	
	/**
	 * @return pltYear
	 */
	public String getPltYear() {
		return pltYear;
	}
	
	/**
	 * @return pltMonth
	 */
	public String getPltMonth() {
		return pltMonth;
	}
	
	/**
	 * @return aryEName
	 */
	public String[] getAryEName() {
		return aryEName.clone();
	}
	
	/**
	 * @return aryEFile
	 */
	public String[] getAryEFile() {
		return aryEFile.clone();
	}
	
	/**
	 * @return aryENameKey
	 */
	public String[] getAryENameKey() {
		return aryENameKey.clone();
	}
	
	/**
	 * @return txtEName
	 */
	public String getTxtEName() {
		return txtEName;
	}
	
	/**
	 * @return txtEFile
	 */
	public String getTxtEFile() {
		return txtEFile;
	}
	
	/**
	 * @return searchmode
	 */
	public int getSearchmode() {
		return searchmode;
	}
	
	/**
	 * @param pltYear Zbg pltYear
	 */
	public void setPltYear(String pltYear) {
		this.pltYear = pltYear;
	}
	
	/**
	 * @param pltMonth Zbg pltMonth
	 */
	public void setPltMonth(String pltMonth) {
		this.pltMonth = pltMonth;
	}
	
	/**
	 * @param aryEName Zbg aryEName
	 */
	public void setAryEName(String[] aryEName) {
		this.aryEName = aryEName.clone();
	}
	
	/**
	 * @param aryEFile Zbg aryEFile
	 */
	public void setAryEFile(String[] aryEFile) {
		this.aryEFile = aryEFile.clone();
	}
	
	/**
	 * @param aryENameKey Zbg aryENameKey
	 */
	public void setAryENameKey(String[] aryENameKey) {
		this.aryENameKey = aryENameKey.clone();
	}
	
	/**
	 * @param txtEName Zbg txtEName
	 */
	public void setTxtEName(String txtEName) {
		this.txtEName = txtEName;
	}
	
	/**
	 * @param txtEFile Zbg txtEFile
	 */
	public void setTxtEFile(String txtEFile) {
		this.txtEFile = txtEFile;
	}
	
	/**
	 * @param searchmode Zbg searchmode
	 */
	public void setSearchmode(int searchmode) {
		this.searchmode = searchmode;
	}
	
}
